==> booking_card_layout-0.0.10.tar.gz: example/lib/home_screen.dart <==
import 'package:booking_card_layout/tv_theme.dart';
import 'package:example/bus_layouts.dart';
import 'package:example/hotel_layouts.dart';
import 'package:example/taxi_layouts.dart';
import 'package:example/train_layouts.dart';
import 'package:flutter/material.dart';
class HomeScreen extends StatefulWidget {
  const HomeScreen({super.key});

  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  int index=0;
  @override
  Widget build(BuildContext context) {
    List<Widget> screens =[const TaxiCardLayouts(),const HotelCardLayout(), const BusLayouts(), const TrainLayouts()];
    return Scaffold(
      bottomNavigationBar: BottomNavigationBar(
        backgroundColor: TVTheme.hotelPie,
        currentIndex: index,
        selectedItemColor: Colors.white,
        onTap: (i){
          setState(() {
            index=i;
          });
        },
        items: const[
           BottomNavigationBarItem(
             icon:Icon( Icons.local_taxi,color: Colors.black,),
             label: "Taxi",
           ),
           BottomNavigationBarItem(
             icon:Icon( Icons.hotel,color: Colors.black,),
             label: "Hotel",
           ),
           BottomNavigationBarItem(
             icon:Icon( Icons.bus_alert_outlined,color: Colors.black,),
             label: "Bus",
           ),
           BottomNavigationBarItem(
             icon:Icon( Icons.train,color: Colors.black,),
             label: "Train",
           ),
        ],
      ),
      body: IndexedStack(
        index: index,
        children: screens,
      ),
    );
  }
}

==> booking_card_layout-0.0.11.tar.gz: example/lib/home_screen.dart <==
import 'package:booking_card_layout/tv_theme.dart';
import 'package:example/bus_layouts.dart';
import 'package:example/flight_layouts.dart';
import 'package:example/hotel_layouts.dart';
import 'package:example/taxi_layouts.dart';
import 'package:example/train_layouts.dart';
import 'package:flutter/material.dart';

class HomeScreen extends StatefulWidget {
  const HomeScreen({super.key});

  @override
  State<HomeScreen> createState() => _HomeScreenState();
}

class _HomeScreenState extends State<HomeScreen> {
  int index=0;
  @override
  Widget build(BuildContext context) {
    List<Widget> screens =[const TaxiCardLayouts(),const HotelCardLayout(), const BusLayouts(), const TrainLayouts(),const FlightLayouts()];
    return Scaffold(
      bottomNavigationBar: BottomNavigationBar(
        backgroundColor: TVTheme.hotelPie,
        currentIndex: index,
        selectedItemColor: Colors.white,
        onTap: (i){
          setState(() {
            index=i;
          });
        },
        items: const[
           BottomNavigationBarItem(
             icon:Icon( Icons.local_taxi,color: Colors.black,),
             label: "Taxi",
           ),
           BottomNavigationBarItem(
             icon:Icon( Icons.hotel,color: Colors.black,),
             label: "Hotel",
           ),
           BottomNavigationBarItem(
             icon:Icon( Icons.bus_alert_outlined,color: Colors.black,),
             label: "Bus",
           ),
           BottomNavigationBarItem(
             icon:Icon( Icons.train,color: Colors.black,),
             label: "Train",
           ),
          BottomNavigationBarItem(
            icon:Icon( Icons.flight,color: Colors.black,),
            label: "Flight",
          ),
        ],
      ),
      body: IndexedStack(
        index: index,
        children: screens,
      ),
    );
  }
}
